// 
// Macro: makeObjectPlots.C
// 
// Purpose: make plots of the variables in the non-SM s-channel analysis.
//
//
#include <vector>

//--------------------------------------------------------------------------------
// functions contained in this file:
//
// make plots of parton level objects
int partonPlots(void); 
// make all plots, i.e. call all other functions
int allPlots(void);
// make plots of angular correlations
int topSpinPlots(void);
// make plots of neural network outputs
int NNPlots(void);
// make plots of jet multiplicity
int njetsPlots(void);
// make plots of reconstructed quantities
int finalObjectPlots(void);
// helper function for fitting: a Gaussian
Double_t Gauss(Double_t *x, Double_t *par);


int allPlots(void)
{
  makePartonPlots();
  topSpinPlots();
  finalObjectPlots();
  NNPlots();

  return 0;
}

//-------------------------------------------------------------------------
//
// make plots of partons
//
int partonPlots(void) 
{
  gROOT->Reset("a");

  gROOT->LoadMacro("defineInputs.C");
  gROOT->LoadMacro("plotSingleHistogram.C");
  gROOT->LoadMacro("../rootutils/CombineHistos.C");


  TObjArray inDirs[2];
  fillDirArray("02_Histogramming_Parton",inDirs[0]);
  //fillDirArray("05_Histogramming_Parton",inDirs[1]);
  

  TString dsuffix[2];
  dsuffix[0]="_parton";
  dsuffix[1]="_aftercuts";
  for(int i=0;i<2;i++) dsuffix[i]+=PlotFileType();

  for(int iDir=0;iDir<1;iDir++) {
    plotHistogram(inDirs[iDir],"TopPtMinusBbarPt","p_{T}(top) - p_{T}(#bar{b}) [GeV]",ddsuffix[iDir],20,2);
    plotHistogram(inDirs[iDir],"bbarpz","p_{z}(#bar{b}) [GeV]",ddsuffix[iDir],20,2);
    return 0; 
    plotHistogram(inDirs[iDir],"InitialWM","M(initial W) [GeV]",dsuffix[iDir],20,2,150.,150.,550.,0.);
    //return 0;
    plotHistogram(inDirs[iDir],"InitialWPt","p_{T}(initial W) [GeV]",dsuffix[iDir],20,2);
    //return 0;
    plotHistogram(inDirs[iDir],"InitialWEta","#eta(initial W)",dsuffix[iDir],20,4);
    //return 0;
    plotHistogram(inDirs[iDir],"bbarpt","p_{T}(#bar{b}) [GeV]",dsuffix[iDir],20,2);
    //return 0;
    plotHistogram(inDirs[iDir],"bbareta","#eta(#bar{b})",dsuffix[iDir]);
    //return 0;
    plotHistogram(inDirs[iDir],"toppt","p_{T}(top) [GeV]",dsuffix[iDir],20,2);
    plotHistogram(inDirs[iDir],"topeta","#eta(top)",dsuffix[iDir]);
    plotHistogram(inDirs[iDir],"TopPtMinusBbarPt",dsuffix[iDir],20,2);
    //return 0;
    plotHistogram(inDirs[iDir],"topmpart","M(top) [GeV]",dsuffix[iDir],20,2,50,150.,200.);
    //return 0;
    plotHistogram(inDirs[iDir],"wpt","p_{T}(W) [GeV]",dsuffix[iDir],20,2);
    plotHistogram(inDirs[iDir],"weta","#eta(W)",dsuffix[iDir]);
    //plotHistogram(inDirs[iDir],"wm","M(W) [GeV]",dsuffix[iDir],20,2,50,50.,100.);
    plotHistogram(inDirs[iDir],"bpt","p_{T}(b) [GeV]",dsuffix[iDir],20,2);
    plotHistogram(inDirs[iDir],"beta","#eta(b)",dsuffix[iDir]);
    //return 0;
    plotHistogram(inDirs[iDir],"elept","p_{T}(electron) [GeV]",dsuffix[iDir],20,2,0.,0.,150.);
    //return 0;
    plotHistogram(inDirs[iDir],"eleeta","#eta(electron)",dsuffix[iDir]);
    plotHistogram(inDirs[iDir],"nupt","#nu p_{T} [GeV]",dsuffix[iDir],20,2,0.,0.,150.);

    plotHistogram(inDirs[iDir],"elebdphi","#Delta#phi(electron,b)",dsuffix[iDir]);
    //return 0;
    plotHistogram(inDirs[iDir],"bbbardphi","#Delta#phi(b,#barb)",dsuffix[iDir]);
    plotHistogram(inDirs[iDir],"elebbardphi","#Delta#phi(electron,#barb)",dsuffix[iDir]);

//     return 0;
//     plotHistogram(inDirs[iDir],"topmpart","M(top) [GeV]",dsuffix[iDir],1,1,40,160,190);
  }

  return 0;
}

//-------------------------------------------------------------------------
//
//
int topSpinPlots(void) 
{
  gROOT->Reset("a");

  gROOT->LoadMacro("defineInputs.C");
  gROOT->LoadMacro("plotSingleHistogram.C");
  gROOT->LoadMacro("../rootutils/CombineHistos.C");


  TObjArray inDirs[2];
  fillDirArray("01_Histogramming_TopSpin",inDirs[0]);
  fillDirArray("08_Histogramming_TopSpin",inDirs[1]);
  

  TString dsuffix[2];
  dsuffix[0]="_parton";
  dsuffix[1]="_aftercuts";
  for(int i=0;i<2;i++) dsuffix[i]+=PlotFileType();

  for(int iDir=0;iDir<2;iDir++) {
    plotHistogram(inDirs[iDir],"InitialWTopCosTheta","cos #theta (initial W,top)_{initial W}",dsuffix[iDir],20,2);
    plotHistogram(inDirs[iDir],"InitialWbbarCosTheta","cos #theta (initial W,#bar{b})_{initial W}",dsuffix[iDir],20,2);
    //return 0;
    plotHistogram(inDirs[iDir],"WTopCosTheta","cos #theta (W,top)_{top}",dsuffix[iDir],20,2);
    //return 0;
    plotHistogram(inDirs[iDir],"bTopCosTheta","cos #theta (b,top)_{top}",dsuffix[iDir],20,2);
   
    plotHistogram(inDirs[iDir],"WeCosTheta","cos #theta (W,e)_{W}",dsuffix[iDir],20,2);
    //return 0;
    // and the s-channel top quark spin correlation plots
    plotHistogram(inDirs[iDir],"PartonCosThetaHel","cos #theta (e,top)_{top}",dsuffix[iDir],20,2);
    //plotHistogram(inDirs[iDir],"PartonCosThetaOpt","cos #theta (e,Z)_{top}",dsuffix[iDir],20,2);
  }

  return 0;
}

//-------------------------------------------------------------------------
//
//
int NNPlots(void) 
{
  gROOT->Reset("a");

  gROOT->LoadMacro("defineInputs.C");
  gROOT->LoadMacro("plotSingleHistogram.C");
  gROOT->LoadMacro("../rootutils/CombineHistos.C");


  TObjArray inDir;
  fillDirArray("09_Histogramming_TopologicalVars",inDir);
  

  plotHistogram(inDir,"NN_e_tb_wbb","NN eCC tb-Wbb",PlotFileType(),20,4);
  plotHistogram(inDir,"NN_e_tb_lepjets","NN eCC tb-t#bar{t}",PlotFileType(),20,2);
  

  return 0;
}

//-------------------------------------------------------------------------
//
//
int njetsPlots(void) 
{
  gROOT->Reset("a");

  gROOT->LoadMacro("defineInputs.C");
  gROOT->LoadMacro("plotSingleHistogram.C");


  TObjArray inDir;
  fillDirArray("03_Histogramming_njets",inDir);
  // njets before and after selection
  plotHistogram(inDir,"njets","number of jets",PlotFileType(),20,0,0);
  
  plotHistogram(inDir,"nbjets","number of b-tagged jets",PlotFileType(),20,0,0);
  fillDirArray("06_Histogramming_njets",inDir);
  plotHistogram(inDir,"njets","number of jets",PlotFileType(),20,0,0);
  //plotHistogram(inDir,"nbjets","number of b-tagged jets",PlotFileType(),20,0);
  

  return 0;
}

//-------------------------------------------------------------------------
//
//
int finalObjectPlots(void) 
{
  gROOT->Reset("a");

  gROOT->LoadMacro("defineInputs.C");
  gROOT->LoadMacro("plotSingleHistogram.C");
  gROOT->LoadMacro("../rootutils/CombineHistos.C");


  TObjArray inDir;
  
  // and object properties
  fillDirArray("07_Histogramming_FinalObjects",inDir);
  plotHistogram(inDir,"Jet1Pt","P_{T} (jet1) [GeV]",PlotFileType(),20,2,0,0.,250.);
  plotHistogram(inDir,"Jet2Pt","P_{T} (jet2) [GeV]",PlotFileType(),20,2,0,0.,150.);
  plotHistogram(inDir,"Jet3Pt","P_{T} (jet3) [GeV]",PlotFileType(),20,2,0,0.,150.);
  plotHistogram(inDir,"elept","P_{T} (lepton) [GeV]",PlotFileType(),20,2,0,0.,150.);
  plotHistogram(inDir,"met","#slash{E}_{T} [GeV]",PlotFileType(),20,2,0,0.,150.);


  return 0;
}

//-------------------------------------------------------------------------
//
//
int topoVarsPlots(void) 
{
  gROOT->Reset("a");

  gROOT->LoadMacro("defineInputs.C");
  gROOT->LoadMacro("plotSingleHistogram.C");
  gROOT->LoadMacro("../rootutils/CombineHistos.C");


  TObjArray inDir;
  fillDirArray("09_Histogramming_TopologicalVars",inDir);
  plotHistogram(inDir,"BTaggedTopMass","M(top_{tagged}) [GeV]",PlotFileType(),20,0,0,100.,250.);
  plotHistogram(inDir,"BestTopMass","M(top_{best}) [GeV]",PlotFileType(),20,0,0,100.,250.);
  plotHistogram(inDir,"LeadingBTaggedJetPt","P_{T}(tagged jet) [GeV]",PlotFileType(),20,2,0,0.,200.);
  plotHistogram(inDir,"Shat","#sqrt{#hat{s}} [GeV]",PlotFileType(),20,2,0,100.,500.);
  plotHistogram(inDir,"DeltaRJet1Jet2","#DeltaR(jet1, jet2)",PlotFileType(),20,2,0,0.,7.);
  plotHistogram(inDir,"LeadingBTaggedJetPt","P_{T}(tagged jet) [GeV]",PlotFileType(),20,2,0,0.,150.);
  plotHistogram(inDir,"Cos_LeptonQZ_BestTop","cos(lepton, Q#timesZ)_{best top}",PlotFileType(),20,2,0);
  plotHistogram(inDir,"Jet1Pt_NotBest","P_{T}(jet1_{not best}) [GeV]",PlotFileType(),20,2,0,0.,150.);
  plotHistogram(inDir,"Jet2Pt_NotBest","P_{T}(jet2_{not best}) [GeV]",PlotFileType(),20,2,0,0.,100.);
  plotHistogram(inDir,"Pt_Jet1Jet2","P_{T}(jet1, jet2) [GeV]",PlotFileType(),20,2,0,0.,200.);
  plotHistogram(inDir,"InvariantMass_AllJets","M(all jets) [GeV]",PlotFileType(),20,2,0);
  plotHistogram(inDir,"TransverseMass_Jet1Jet2","M_{T}(jet1, jet2) [GeV]",PlotFileType(),20,2,0,0.,200.);
  plotHistogram(inDir,"InvariantMass_AllJets_MinusBestJet","M(all jets minus best jet) [GeV]",PlotFileType(),20,2,0);
  plotHistogram(inDir,"H_AllJets_MinusBestJet","H(all jets minus best jet) [GeV]",PlotFileType(),20,2,0);
  plotHistogram(inDir,"HT_AllJets_MinusBestJet","HT(all jets minus best jet) [GeV]",PlotFileType(),20,2,0,0.,250.);
  plotHistogram(inDir,"H_AllJets_MinusBTaggedJet","H(all jets minus b-tagged jet) [GeV]",PlotFileType(),20,2,0);
  plotHistogram(inDir,"Pt_AllJets_MinusBTaggedJet","PT(all jets minus b-tagged jet) [GeV]",PlotFileType(),20,2,0);
  plotHistogram(inDir,"Cos_NotBestJetAllJets_AllJets","cos(not-best jet, all jets)_{all jets}",PlotFileType(),20,2,0);

  plotHistogram(inDir,"DeltaPt_Jet1Jet2","#DeltaP_{T} (jet1,jet2) [GeV]",PlotFileType(),20,2,0);
  plotHistogram(inDir,"DeltaRJet1Jet2","#DeltaR (jet1,jet2)",PlotFileType(),20,2,0,0.,6.);
  

  return 0;
}

//-------------------------------------------------------------------------
//
// make plots comparing positive and negative charged top quark distributions
//
//
int findReweightFunction(void) 
{
  gROOT->ProcessLine(".L ../rootutils/CombineHistos.C");


  // open the histogram file
  TFile  *file1000=new TFile(HistoFile1000);
  TFile  *file0100=new TFile(HistoFile0100);


  TObjArray inDirs[2];
  // check that the directories actually exist
  inDirs[0].Add(file1000->Get("02_Histogramming_TopSpin"));
  inDirs[0].Add(file0100->Get("02_Histogramming_TopSpin"));


  TCanvas *c1 = new TCanvas("reWeight","",50,44,600,500);
  // make more space for the Y-axis title
  c1->SetLeftMargin( .21); // default is 10%
  c1->SetBottomMargin(0.15);
  

  // arrays for histograms, legends, colors, and line styles
  TDirectory *td;
  TObjArray tempHistos;
  TObject *tempo;
  int nPlots=0;

  // legends for the histograms
  TString legends[15]={"1000","1000 plus","1000 minus",
		       "0100","0100 plus","0100 minus",
		       "1010","1010 plus","1010 minus",
		       "1001","1001 plus","1001 minus",  
		       "1111","1111 plus","1111 minus"};
  Int_t palette[15]={1,2,4, 2,1,4, 4,1,2, 3,1,2, 37,1,2};
  Int_t styles[15]= {1,2,3, 2,1,3, 3,1,2, 4,1,2,  1,2,3};


  TString name="PartonCosThetaHel";
  // plot cos theta in the helicity basis,
  // for the FL1 and FR1 samples
  td=(TDirectory*) inDirs[0][0];
  td=(TDirectory*) td->Get("inclusive");
  tempo = td->Get(name.Data());
  if(tempo==0) {
    cout<<"Error: null pointer for histogram in file "<<iF<<endl;
    return -1;
  }
  tempHistos.Add(tempo);
  legends[0]="FL1";

  td=(TDirectory*) inDirs[0][1];
  td=(TDirectory*) td->Get("inclusive");
  tempo = td->Get(name.Data());
  if(tempo==0) {
    cout<<"Error: null pointer for histogram in file "<<iF<<endl;
    return -1;
  }
  tempHistos.Add(tempo);
  legends[1]="FR1";

  // now fit the two histograms
  TH1F *temph;
  TF1 *f1[2];
  for(int i=0;i<tempHistos.GetEntriesFast();i++) {
    temph=(TH1F*) tempHistos[i];
    f1[i]=new TF1("f1","pol1",-1.,1.);
    temph->Fit("f1","RCNQ");
  }
  
  // fit result:
  


  float xmin=-99999.;
  float xmax=-1.;
  float ymin=-99999.;
  float ymax=-1.;
  bool normalize=false;
  bool drawLine=false;
  int rebin=1;
  int smoothen=400;
  int legendCorner=1;
  TString suffix=PLOTFILETYPE;

  CombineHistos(tempHistos,legends,name.Data(),"cos(#theta)_{hel}","#sigma",palette,styles,legendCorner,smoothen,rebin,drawLine,normalize,xmin,xmax,-1.,ymin,ymax);
  
  // and write the plot to file
  c1->SaveAs(PlotTargetDir+"/"+"rebinSpin"+suffix);
  return 0;

}

// //-----------------------------------------------------------------------------------
// //
// // make plots of reconstructed quantities
// //
// int makeFinalObjectPlots(void) 
// {
//   gROOT->ProcessLine(".L plotSingleHistogram.C");


//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   TDirectory *d;

//   TString partonstr="_parton";
//   partonstr+=PLOTFILETYPE;

//   // plot n_jets before making any cuts
//   d=(TDirectory*)file->Get("01_Histogramming_njets");
 
//   plotHistogram(d,"njets","number of jets","sums",partonstr);
//   plotHistogram(d,"njets","number of jets","alpha_s_only",partonstr);
//   plotHistogram(d,"nbjets","number of b jets","sums",partonstr);
//   plotHistogram(d,"nbjets","number of b jets","alpha_s_only",partonstr);
  
//   // plot njets after cuts
//   // after final cuts
//   d=(TDirectory*)file->Get("04_Histogramming_njets");
//   plotHistogram(d,"njets","number of jets","sums");
//   plotHistogram(d,"njets","number of jets","alpha_s_only",PLOTFILETYPE);
//   //plotHistogram(d,"njets","number of jets","nlo_tree_scale");
//   plotHistogram(d,"nbjets","number of b-tagged jets","sums");
//   plotHistogram(d,"nbjets","number of b-tagged jets","alpha_s_only");
//   //plotHistogram(d,"nbjets","number of b-tagged jets","nlo_tree_scale");
//   plotHistogram(d,"IsbTaggedJet","Is the jet a b-jet?","sums",PLOTFILETYPE,1,-1,-1);
//   //
//   // now plot reconstructed quantities after cuts
//   d=(TDirectory*)file->Get("05_Histogramming_FinalObjects");
 
//   plotHistogram(d,"elept","Electron p_{T} [GeV]","sums",PLOTFILETYPE,1,4,20,0.,200.);
//   plotHistogram(d,"elept","Electron p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,4,20,0.,200.);
//   plotHistogram(d,"elept","Electron p_{T} [GeV]","nlo_tree_scale",PLOTFILETYPE,1,4,20,0.,200.);

//   plotHistogram(d,"met","#slash{E}_{T} [GeV]","sums",PLOTFILETYPE,1,4,20,0.,200.);
//   plotHistogram(d,"met","#slash{E}_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,4,20,0.,200.);
//   plotHistogram(d,"met","#slash{E}_{T} [GeV]","nlo_tree_scale",PLOTFILETYPE,1,4,20,0.,200.);


//   plotHistogram(d,"Jet1Pt","Jet 1 p_{T} [GeV]","sums",PLOTFILETYPE,1,4,50);
//   plotHistogram(d,"Jet1Pt","Jet 1 p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,4,50);
//   plotHistogram(d,"Jet1Pt","Jet 1 p_{T} [GeV]","nlo_tree_scale",PLOTFILETYPE,1,4,50);
//   plotHistogram(d,"Jet2Pt","Jet 2 p_{T} [GeV]","sums",PLOTFILETYPE,1,3,20);
//   plotHistogram(d,"Jet2Pt","Jet 2 p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,3,20);
//   plotHistogram(d,"Jet2Pt","Jet 2 p_{T} [GeV]","nlo_tree_scale",PLOTFILETYPE,1,3,20);
//   //plotHistogram(d,"Jet3Pt","P_T [GeV]","sums"); // no 3rd jet at LO
//   plotHistogram(d,"Jet3Pt","Jet 3 p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,3,20);
  
//   // reconstructed b and bbar jet
//   plotHistogram(d,"bJetPt","Jet_{b} p_{T} [GeV]","sums",PLOTFILETYPE,1,5,50);
//   plotHistogram(d,"bJetPt","Jet_{b} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,5,120);
//   plotHistogram(d,"bJetPt","Jet_{b} p_{T} [GeV]","alpha_s_tree_scale4",PLOTFILETYPE,1,5,120);
  
//   plotHistogram(d,"bbarJetPt","Jet_{#bar{b}} p_{T} [GeV]","sums",PLOTFILETYPE,1,5,40);
//   plotHistogram(d,"bbarJetPt","Jet_{#bar{b}} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,5,200);
//   plotHistogram(d,"bbarJetPt","Jet_{#bar{b}} p_{T} [GeV]","alpha_s_tree_scale4",PLOTFILETYPE,1,5,200);
  
//   // reconstructed b and bbar jet, split up into different cases
//   plotHistogram(d,"bJetPt2","Jet_{b} p_{T} [GeV]","sums",PLOTFILETYPE,1,5,50);
//   plotHistogram(d,"bJetPt2","Jet_{b} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,5,120);
//   plotHistogram(d,"bJetPt3","Jet_{b} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,5,50);
//   plotHistogram(d,"bbarJetPt2","Jet_{#bar{b}} p_{T} [GeV]","sums",PLOTFILETYPE,1,5,40);
//   plotHistogram(d,"bbarJetPt2","Jet_{#bar{b}} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,5,200);
//   plotHistogram(d,"bbarJetPt3","Jet_{#bar{b}} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,5,200);
 
//   plotHistogram(d,"gluonJetpt3","Jet_{g} E_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,3,30);

//   plotHistogram(d,"gluonSecondJetpt","Jet_{g} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,3,30);

//   plotHistogram(d,"bbbarOneJetpt","Jet_{b,#bar{b}} p_{T} [GeV]","alpha_s_only",PLOTFILETYPE,1,3,40);

//   // and the corresponding eta distributions
//   // reconstructed b and bbar jet
//   plotHistogram(d,"bJetEta","Jet_{b} #eta","sums",PLOTFILETYPE);
//   plotHistogram(d,"bJetEta","Jet_{b} #eta","alpha_s_only",PLOTFILETYPE,1,1,400);
//   plotHistogram(d,"bJetEta","Jet_{b} #eta","alpha_s_tree_scale4",PLOTFILETYPE);
//   plotHistogram(d,"bbarJetEta","Jet_{#bar{b}} #eta","sums",PLOTFILETYPE);
//   plotHistogram(d,"bbarJetEta","Jet_{#bar{b}} #eta","alpha_s_only",PLOTFILETYPE,1,1,400);
//   plotHistogram(d,"bbarJetEta","Jet_{#bar{b}} #eta","alpha_s_tree_scale4",PLOTFILETYPE);
  
//   //  reconstructed b and bbar jet, split up into different cases
//   plotHistogram(d,"bJetEta2","Jet_{b} #eta","sums",PLOTFILETYPE);
//   plotHistogram(d,"bJetEta2","Jet_{b} #eta","alpha_s_only",PLOTFILETYPE,1,1,400);
//   plotHistogram(d,"bJetEta3","Jet_{b} #eta","alpha_s_only",PLOTFILETYPE);
//   plotHistogram(d,"bbarJetEta2","Jet_{#bar{b}} #eta","sums",PLOTFILETYPE);
//   plotHistogram(d,"bbarJetEta2","Jet_{#bar{b}} #eta","alpha_s_only",PLOTFILETYPE,1,1,400);
//   plotHistogram(d,"bbarJetEta3","Jet_{#bar{b}} #eta","alpha_s_only",PLOTFILETYPE);
//   plotHistogram(d,"gluonJeteta3","Jet_{g} #eta","alpha_s_only",PLOTFILETYPE);
//   plotHistogram(d,"gluonSecondJeteta","Jet_{g} #eta","alpha_s_only",PLOTFILETYPE);

//   plotHistogram(d,"bbbarOneJeteta","Jet_{b,#bar{b}} #eta","alpha_s_only",PLOTFILETYPE);
  
//   // eta distributions
//   plotHistogram(d,"eleeta","Electron #eta","sums");
//   plotHistogram(d,"eleeta","Electron #eta","alpha_s_only");
//   plotHistogram(d,"eleeta","Electron #eta","nlo_tree_scale");

//   plotHistogram(d,"Jet1Eta","Jet 1 #eta","sums");
//   plotHistogram(d,"Jet1Eta","Jet 1 #eta","alpha_s_only");
//   plotHistogram(d,"Jet1Eta","Jet 1 #eta","nlo_tree_scale");
//   plotHistogram(d,"Jet2Eta","Jet 2 #eta","sums");
//   plotHistogram(d,"Jet2Eta","Jet 2 #eta","alpha_s_only",PLOTFILETYPE,1,2);
//   plotHistogram(d,"Jet2Eta","Jet 2 #eta","nlo_tree_scale");
//   //plotHistogram(d,"Jet3Eta","#Eta","sums");
//   plotHistogram(d,"Jet3Eta","Jet 3 #eta","alpha_s_only");
//   // don't close the file for now, otherwise the histo won't show up
//   //cout<<"closing file"<<endl;
//   //file->Close();
//   //delete file;
//   return 0;
// }

// //-------------------------------------------------------------------------
// //
// // make plots of gluons (and gluon jets) and their relation ship to b and bbar jets.
// //
// int makeGluonMatchPlots(void) 
// {
//   gROOT->ProcessLine(".L plotSingleHistogram.C");


//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   std::vector<TDirectory*> d;
//   // plot gluon related distributions
//   // after cuts
//   d.push_back((TDirectory*)file->Get("07_Histogramming_GluonMatch"));
//   TString dsuffix[2];
//   //dsuffix[0]="_parton";
//   dsuffix[0]="_aftercuts";
//   for(int i=0;i<2;i++) dsuffix[i]+=PLOTFILETYPE;

//   // only loop once, no more parton level plots for reconstructed objects!
//   //
//   for(int i=0;i<1;i++) {
//     plotHistogram(d[i],"gluonjet1dR","#DeltaR(g,jet_{1})","alpha_s_only",dsuffix[i]);
//     plotHistogram(d[i],"gluonjet2dR","#DeltaR(g,jet_{2})","alpha_s_only",dsuffix[i]);
//     plotHistogram(d[i],"gluonjet3dR","#DeltaR(g,jet_{3})","alpha_s_only",dsuffix[i]);
//     plotHistogram(d[i],"gluonjet1dphi","#Delta#phi(g,jet_{1})","alpha_s_only",dsuffix[i]);
//     plotHistogram(d[i],"gluonjet2dphi","#Delta#phi(g,jet_{2})","alpha_s_only",dsuffix[i]);
//     plotHistogram(d[i],"gluonjet3dphi","#Delta#phi(g,jet_{3})","alpha_s_only",dsuffix[i]);

//     plotHistogram(d[i],"gluonJetbJetdphi","#Delta#phi(jet_{g},jet_{b})","alpha_s_only",dsuffix[i],20,1,400,-99999.,-1.,0.,4.);
//     plotHistogram(d[i],"gluonJetbbarJetdphi","#Delta#phi(jet_{g},jet_{#bar{b}})","alpha_s_only",dsuffix[i],20,1,400,-99999.,-1.,0.,4.);
  
//     plotHistogram(d[i],"gluonJetbJetdr","#DeltaR(jet_{g},jet_{b})","alpha_s_only",dsuffix[i],1,2,4);
//     plotHistogram(d[i],"gluonJetbbarJetdr","#DeltaR(jet_{g},jet_{#bar{b}})","alpha_s_only",dsuffix[i],1,2,4);
//     plotHistogram(d[i],"gluonJetbJetdphi","#Delta#phi(jet_{g},jet_{b})","alpha_s_only",dsuffix[i],20,3,10,-99999.,-1.,0.,3.);
//     plotHistogram(d[i],"gluonJetbbarJetdphi","#Delta#phi(jet_{g},jet_{#bar{b}})","alpha_s_only",dsuffix[i],20,3,10,-99999.,-1.,0.,3.);
   
//     plotHistogram(d[i],"Jet3BgJetdR","#DeltaR(jet_{3},jet_{best jet})","alpha_s_only",dsuffix[i],20,1,400,0.,6.);
//     plotHistogram(d[i],"Jet3NonBgJetdR","#DeltaR(jet_{3},jet_{non-best jet})","alpha_s_only",dsuffix[i],20,1,400,0.,6.);
//   }

// }


// //-------------------------------------------------------------------------
// //
// // make plots of reconstructed top mass
// //
// int makeFinalTopMassPlots(void) 
// {
//   gROOT->ProcessLine(".L plotSingleHistogram.C");


//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   std::vector<TDirectory*> d;
//   // plot parton distributions
//   // before any cuts
//   //d.push_back((TDirectory*)file->Get("02_Histogramming_FinalTopMass"));
//   // and after cuts
//   d.push_back((TDirectory*)file->Get("06_Histogramming_FinalTopMass"));
//   TString dsuffix[2];
//   //dsuffix[0]="_parton";
//   dsuffix[0]="_aftercuts";
//   for(int i=0;i<2;i++) dsuffix[i]+=PLOTFILETYPE;

//   // only loop once, cannot reconstruct top infrared-safely without pt cuts on jets!
//   //
//   for(int i=0;i<1;i++) {
//     //    plotHistogram(d[i],"bestJetEta","best jet #eta","sums",dsuffix[i]);
//     //plotHistogram(d[i],"bestJetEta","best jet #eta","alpha_s_only",dsuffix[i]);
//     //plotHistogram(d[i],"bestJetEta","best jet #eta","alpha_s_tree_scale4",dsuffix[i]);
    
//     // use best jet from 1,2 instead!
//     //plotHistogram(d[i],"topmbestjet","M(top_{best jet}) [GeV]","sums",dsuffix[i],1,1,40);
//     //plotHistogram(d[i],"topmbestjet","M(top_{best jet}) [GeV]","alpha_s_only",dsuffix[i],1,1,80);
//     //plotHistogram(d[i],"topmbestjet","M(top_{best jet}) [GeV]","nlo_tree_scale",dsuffix[i],1,1,80);

//     plotHistogram(d[i],"topmparton","M(top_{parton}) [GeV]","sums",dsuffix[i],1,1,4);
//     plotHistogram(d[i],"topmparton","M(top_{parton}) [GeV]","alpha_s_only",dsuffix[i],1,1,4);
//     plotHistogram(d[i],"topmparton","M(top_{parton}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,1,4);
  
//     // not physical to exclude the gluon!
//     //plotHistogram(d[i],"topmpartng","M(top_{parton, no g}) [GeV]","sums",dsuffix[i]);
//     //plotHistogram(d[i],"topmpartng","M(top_{parton, no g}) [GeV]","alpha_s_only",dsuffix[i]);
//     //plotHistogram(d[i],"topmpartng","M(top_{parton, no g}) [GeV]","nlo_tree_scale",dsuffix[i]);

//     plotHistogram(d[i],"topmbestjet12","M(top_{best jet}) [GeV]","sums",dsuffix[i],1,1,40);
//     plotHistogram(d[i],"topmbestjet12","M(top_{best jet}) [GeV]","alpha_s_only",dsuffix[i],1,1,60);
//     plotHistogram(d[i],"topmbestjet12","M(top_{best jet}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,1,60);

//     plotHistogram(d[i],"topmleadjet","M(top_{leading jet}) [GeV]","sums",dsuffix[i],20,1,40);
//     plotHistogram(d[i],"topmleadjet","M(top_{leading jet}) [GeV]","alpha_s_only",dsuffix[i],1,1,60);
//     plotHistogram(d[i],"topmleadjet","M(top_{leading jet}) [GeV]","alpha_s_tree_scale4",dsuffix[i],20,1,60);

//     plotHistogram(d[i],"topmjet12","M(top_{any jet}) [GeV]","sums",dsuffix[i],20,1,15);
//     plotHistogram(d[i],"topmjet12","M(top_{any jet}) [GeV]","alpha_s_only",dsuffix[i],20,1,30);
//     plotHistogram(d[i],"topmjet12","M(top_{any jet}) [GeV]","alpha_s_tree_scale4",dsuffix[i],20,1,40);
    
//     plotHistogram(d[i],"topmbgjet","M(top_{best jet}) [GeV]","sums",dsuffix[i],1,1,40);
//     plotHistogram(d[i],"topmbgjet","M(top_{best jet}) [GeV]","alpha_s_only",dsuffix[i],1,1,60);
//     plotHistogram(d[i],"topmbgjet","M(top_{best jet}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,1,60);
//     // and the reconstructed top pt and eta
//     plotHistogram(d[i],"bgTopPt","top p_{T} [GeV]","sums",dsuffix[i],1,5,30,0.,200.);    
//     plotHistogram(d[i],"bgTopPt","top p_{T} [GeV]","alpha_s_only",dsuffix[i],1,5,30,0.,200.);    
//     plotHistogram(d[i],"bgTopPt","top p_{T} [GeV]","alpha_s_tree_scale4",dsuffix[i],1,5,30,0.,200.);    

//     plotHistogram(d[i],"bgTopEta","top #eta","sums",dsuffix[i]);
//     plotHistogram(d[i],"bgTopEta","top #eta","alpha_s_only",dsuffix[i]);    
//     plotHistogram(d[i],"bgTopEta","top #eta","alpha_s_tree_scale4",dsuffix[i]);    

//     plotHistogram(d[i],"bgTopRapidity","top rapidity","sums",dsuffix[i]);
//     plotHistogram(d[i],"bgTopRapidity","top rapidity","alpha_s_only",dsuffix[i]);    
//     plotHistogram(d[i],"bgTopRapidity","top rapidity","alpha_s_tree_scale4",dsuffix[i]);    

//     // also plot properties of the bg jet and the non-bg jet and the top quark made from that
//     plotHistogram(d[i],"bgJetPt","best jet p_{T} [GeV]","sums",dsuffix[i],1,3,50,0.,150.);    
//     plotHistogram(d[i],"bgJetPt","best jet p_{T} [GeV]","alpha_s_only",dsuffix[i],1,3,50,0.,150.);    
//     plotHistogram(d[i],"bnongJetPt","non-best jet p_{T} [GeV]","sums",dsuffix[i],1,4,50,0.,200.);    
//     plotHistogram(d[i],"bnongJetPt","non-best jet p_{T} [GeV]","alpha_s_only",dsuffix[i],1,5,50,0.,200.);    

//     plotHistogram(d[i],"bgJetEta","best jet #eta","sums",dsuffix[i]);
//     plotHistogram(d[i],"bgJetEta","best jet #eta","alpha_s_only",dsuffix[i]);    
//     plotHistogram(d[i],"bnongJetEta","non-best jet #eta","sums",dsuffix[i]);
//     plotHistogram(d[i],"bnongJetEta","non-best jet #eta","alpha_s_only",dsuffix[i]);    

//   }

// }

// //-------------------------------------------------------------------------
// //
// // make plots comparing different mass reconstruction algorithms
// //
// int makeTopMassComparisonPlots(void) 
// {
//   gROOT->ProcessLine(".L ../rootutils/CombineHistos.C");


//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   TCanvas *c1 = new TCanvas("topmass","",50,44,600,500);
//   // make more space for the Y-axis title
//   c1->SetLeftMargin( .21); // default is 10%
//   c1->SetBottomMargin(0.15);
  

//   // arrays for histograms, legends, colors, and line styles
//   TObjArray histos;
//   int nPlots=0;
//   TString legends[13]={"all","Born","NLO","no dec",
// 		       "FINAL","initial a","initial b","initial c",
// 		       "svc ini","svc fin","svc dec","SDEC","temp"};
//   Int_t palette[13]={1,2,4,3, 7,9,9,9, 9,7,3,3};
//   Int_t styles[13]= {1,2,3,4, 1,2,3,4, 1,4,3,2};
//   // all plots are after cuts
//   // 
//   // the plots from the mass directory
//   TDirectory *dmass = (TDirectory*)(file->Get("06_Histogramming_FinalTopMass"));
//   dmass = (TDirectory)(dmass->Get("tree_nlo"));

  
//   // for comparison: the b jet (with gluon in decay case)
//   TH1F *temphist;
//   // temporary fix: if the histogram topmbjetg doesn't exist yet, we are looking 
//   // at an old file.
//   if(dmass->Get("topmbjetg")==0) {
//     temphist=(TH1F*) (dmass->Get("topmbjet"))->Clone();
//   }
//   else {
//     temphist=(TH1F*) (dmass->Get("topmbjet"))->Clone();
//   }
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="true b jet";
//   nPlots++;
//   // and the best jet with gluon
//   temphist=(TH1F*) (dmass->Get("topmbgjet"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="best jet";
//   nPlots++;
//   // the leading jet:
//   temphist=(TH1F*) (dmass->Get("topmleadjet"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="leading jet";
//   nPlots++;

//   // finally, plot!
//   int smoothen=8;
//   int rebin=0;
//   CombineHistos(histos,legends,"top_mass_compare","M(top) [GeV]","#sigma [fb/GeV]",palette,styles,20,smoothen,rebin,true,false,160.,190.);
//   // and write the plot to file
//   c1->SaveAs(PlotTargetDir+"/topmass_compare"+PLOTFILETYPE);
  
//   // and make another one, adding in the parton level plot
//   // put the parton level top mass after cuts 
//   TDirectory *dparton = (TDirectory*)(file->Get("03_Histogramming_Parton"));
//   dparton = (TDirectory*)(dparton->Get("tree_nlo"));
//   // parton level mass with and without gluon
//   temphist=(TH1F*) (dparton->Get("topmpart"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="parton";
//   nPlots++;

//   CombineHistos(histos,legends,"top_mass_compare_parton","M(top) [GeV]","#sigma [fb/GeV]",palette,styles,20,smoothen,rebin,true,false,160.,190.);
//   // and write the plot to file
//   c1->SaveAs(PlotTargetDir+"/topmass_compare_parton"+PLOTFILETYPE);

//   return 0;
// }

// //--------------------------------------------------------------------------------------
// //
// // make some plots about the bbbar system
// //
// int makebbbarPlots(void) 
// {
//   gROOT->ProcessLine(".L plotSingleHistogram.C");


//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);


//   std::vector<TDirectory*> d;
//   // plot parton distributions
//   //  after cuts
//   d.push_back((TDirectory*)file->Get("08_Histogramming_bbbar"));
//   TString dsuffix[2];
//   //dsuffix[0]="_parton";
//   dsuffix[0]="_aftercuts";
//   for(int i=0;i<2;i++) dsuffix[i]+=PLOTFILETYPE;

//   TDirectory *dTemp;
//   TH1F *hTemp;

//   // only make plots after cuts!
//   //
//   for(int i=0;i<1;i++) {

//     //
//     // parton level plots
//     plotHistogram(d[i],"bbbardR","#DeltaR(b,#bar{b})","sums",dsuffix[i]);
//     plotHistogram(d[i],"bbbardR","#DeltaR(b,#bar{b})","alpha_s_only",dsuffix[i]);
  
//     plotHistogram(d[i],"bbbarM","M(b,#bar{b}) [GeV]","sums",dsuffix[i],1,8,400);
//     plotHistogram(d[i],"bbbarM","M(b,#bar{b}) [GeV]","alpha_s_only",dsuffix[i],1,8,400);
//     // 
//     // plots for b jet and bbar jet after reconstruction
//     plotHistogram(d[i],"bJetbbarJetdR","#DeltaR(jet_{b},jet_{#bar{b}})","sums",dsuffix[i]);
//     plotHistogram(d[i],"bJetbbarJetdR","#DeltaR(jet_{b},jet_{#bar{b}})","alpha_s_only",dsuffix[i]);
    
//     plotHistogram(d[i],"bJetbbarJetM","M(jet_{b},jet_{#bar{b}}) [GeV]","sums",dsuffix[i],1,8,400);
//     plotHistogram(d[i],"bJetbbarJetM","M(jet_{b},jet_{#bar{b}}) [GeV]","alpha_s_only",dsuffix[i],1,8,400);
//     // same thing, but adjust x range
//     plotHistogram(d[i],"bJetbbarJetM","M(jet_{b},jet_{#bar{b}}) [GeV]","sums","_zoom"+dsuffix[i],1,8,400,80.,140.,0.,0.25);
//     plotHistogram(d[i],"bJetbbarJetM","M(jet_{b},jet_{#bar{b}}) [GeV]","alpha_s_only","_zoom"+dsuffix[i],1,8,400,80.,140.,-0.01,0.11);
//     // 
//     // reconstruction jet  plots
//     plotHistogram(d[i],"jet12dR","#DeltaR(jet_{1},jet_{2})","sums",dsuffix[i]);
//     plotHistogram(d[i],"jet12dR","#DeltaR(jet_{1},jet_{2})","alpha_s_only",dsuffix[i]);
  
//     plotHistogram(d[i],"jet12M","M(jet_{1},jet_{2}) [GeV]","sums",dsuffix[i],1,8,400);
//     plotHistogram(d[i],"jet12M","M(jet_{1},jet_{2}) [GeV]","alpha_s_only",dsuffix[i],1,8,400);
//     // same thing, but adjust x range
//     plotHistogram(d[i],"jet12M","M(jet_{1},jet_{2}) [GeV]","sums","_zoom"+dsuffix[i],1,8,400,80.,140.,0.,0.25);
//     plotHistogram(d[i],"jet12M","M(jet_{1},jet_{2}) [GeV]","alpha_s_only","_zoom"+dsuffix[i],1,8,400,80.,140.,-0.01,0.12);
    
//     // distributions of PT minus PT
//     plotHistogram(d[i],"Jet1PtMJet2Pt","P_{T}(jet_{1}) - P_{T}(jet_{2}) [GeV]","sums",dsuffix[i],20,4,50,0.,100.);
//     plotHistogram(d[i],"Jet1PtMJet2Pt","P_{T}(jet_{1}) - P_{T}(jet_{2}) [GeV]","alpha_s_only",dsuffix[i],20,4,50,0.,100.);
    
//     plotHistogram(d[i],"bJetPtMbbarJetPt",
// 		  "P_{T}(jet_{b}) - P_{T}(jet_{#bar{b}}) [GeV]","sums",dsuffix[i],1,4,50);
//     plotHistogram(d[i],"bJetPtMbbarJetPt",
// 		  "P_{T}(jet_{b}) - P_{T}(jet_{#bar{b}}) [GeV]","alpha_s_only",dsuffix[i],1,4,100);
//     plotHistogram(d[i],"bJetPtMbbarJetPt",
// 		  "P_{T}(jet_{b}) - P_{T}(jet_{#bar{b}}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,4,100);

//     plotHistogram(d[i],"bgBestJetPtMNonBestJetPt",
// 		  "P_{T}(jet_{best}) - P_{T}(jet_{non-best}) [GeV]","sums",dsuffix[i],1,4,50);
//     plotHistogram(d[i],"bgBestJetPtMNonBestJetPt",
// 		  "P_{T}(jet_{best}) - P_{T}(jet_{non-best}) [GeV]","alpha_s_only",dsuffix[i],1,4,50);
//     plotHistogram(d[i],"bgBestJetPtMNonBestJetPt",
// 		  "P_{T}(jet_{best}) - P_{T}(jet_{non-best}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,4,50);

//     // also plot eta differences
//     plotHistogram(d[i],"bJetEtaMbbarJetEta",
// 		  "#eta(jet_{b}) - #eta(jet_{#bar{b}}) [GeV]","sums",dsuffix[i],1,4,50);
//     plotHistogram(d[i],"bJetEtaMbbarJetEta",
// 		  "#eta(jet_{b}) - #eta(jet_{#bar{b}}) [GeV]","alpha_s_only",dsuffix[i],1,4,50);
//     plotHistogram(d[i],"bJetEtaMbbarJetEta",
// 		  "#eta(jet_{b}) - #eta(jet_{#bar{b}}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,4,50);

//     plotHistogram(d[i],"bgBestJetEtaMNonBestJetEta",
// 		  "#eta(jet_{best}) - #eta(jet_{non-best}) [GeV]","sums",dsuffix[i],1,4,100);
//     plotHistogram(d[i],"bgBestJetEtaMNonBestJetEta",
// 		  "#eta(jet_{best}) - #eta(jet_{non-best}) [GeV]","alpha_s_only",dsuffix[i],1,4,300);
//     plotHistogram(d[i],"bgBestJetEtaMNonBestJetEta",
// 		  "#eta(jet_{best}) - #eta(jet_{non-best}) [GeV]","alpha_s_tree_scale4",dsuffix[i],1,4,300);
    
//     // also reconstruct a "Higgs" from the b and bbar and plot cos theta of the b with respect to that
//     plotHistogram(d[i],"bJetCosThetaHiggsFrame","cos(#theta) (jet_{b},b#bar{b})","sums",dsuffix[i],1,4,30);
//     plotHistogram(d[i],"bJetCosThetaHiggsFrame","cos(#theta) (jet_{b},b#bar{b})","alpha_s_only",dsuffix[i],1,4,30);
//     plotHistogram(d[i],"bJetCosThetaHiggsFrame","cos(#theta) (jet_{b},b#bar{b})","alpha_s_tree_scale4",dsuffix[i],1,4,30);
    
//     // same thing for bbar
//     plotHistogram(d[i],"bbarJetCosThetaHiggsFrame","cos(#theta) (jet_{b},b#bar{b})","sums",dsuffix[i],1,4,30);
//     plotHistogram(d[i],"bbarJetCosThetaHiggsFrame","cos(#theta) (jet_{b},b#bar{b})","alpha_s_only",dsuffix[i],1,4,30);
//     plotHistogram(d[i],"bbarJetCosThetaHiggsFrame","cos(#theta) (jet_{b},b#bar{b})","alpha_s_tree_scale4",dsuffix[i],1,4,30);
    
//     plotHistogram(d[i],"bgBestJetCosThetaHiggsFrame",
// 		  "cos(#theta) (jet_{best},b#bar{b})","sums",dsuffix[i],10,4,30);
//     plotHistogram(d[i],"bgBestJetCosThetaHiggsFrame",
// 		  "cos(#theta) (jet_{best},b#bar{b})","alpha_s_only",dsuffix[i],1,4,30);
//     plotHistogram(d[i],"bgBestJetCosThetaHiggsFrame",
// 		  "cos(#theta) (jet_{best},b#bar{b})","alpha_s_tree_scale4",dsuffix[i],1,4,30);

    
//     TString subDirNames[12]={"tree_nlo","tree","nlo_all","nlo_nodec",
// 			     "final","inita","initb","initc",
// 			     "svci","svcf","svcd","decay"};
//     // also make plots of cos theta for the b and bbar sum 
//     // because experimentally we won't be able to tell the difference.
//     for(int j=0;j<12;j++) {
//       dTemp=(TDirectory*) (((TDirectory*) d[i])->Get(subDirNames[j]));
//       dTemp->cd();
//       hTemp=(TH1F*) dTemp->Get("bJetCosThetaHiggsFrame")->Clone("bbbarCosTheta");
//       hTemp->Add((TH1F*) dTemp->Get("bbarJetCosThetaHiggsFrame"));
//       hTemp->Scale(0.5);
//     }
//     file->cd();
    
//     plotHistogram(d[i],"bbbarCosTheta","cos(#theta) (jet,b#bar{b})","sums",dsuffix[i],1,4,30,-1.,1.,0.,25.);
//     plotHistogram(d[i],"bbbarCosTheta","cos(#theta) (jet,b#bar{b})","alpha_s_only",dsuffix[i],1,4,30,-1.,1.,-3.,11.);
//     plotHistogram(d[i],"bbbarCosTheta","cos(#theta) (jet,b#bar{b})","alpha_s_tree_scale4",dsuffix[i],1,4,30);
    

//   } // end of loop over directories


// }

// //-------------------------------------------------------------------------
// //
// // Make plots comparing b jet PT with bbar jet PT,
// // at tree level, and for full NLO
// // Also plot eta
// //
// int makebJetbbarJetComparisonPlots(void) 
// {
//   gROOT->ProcessLine(".L ../rootutils/CombineHistos.C");


//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   TCanvas *c1 = new TCanvas("topbbbar","",50,44,600,500);
//   // make more space for the Y-axis title
//   c1->SetLeftMargin( .22); // default is 10%
//   c1->SetBottomMargin(0.15);
  

//   std::vector<TDirectory*> d;
//   // plot parton distributions
//   // and after cuts
//   d.push_back((TDirectory*)file->Get("05_Histogramming_FinalObjects"));
//   TString dsuffix[2];
//   dsuffix[0]="_aftercuts";
//   for(int i=0;i<2;i++) dsuffix[i]+=PLOTFILETYPE;

//   TObjArray histos,histosEta;
//   TString legends[12]={"all","Born","O(#alpha_{s})","no dec",
// 		       "final","initial a","initial b","initial c",
// 		       "svc ini","svc fin","svc dec","decay"};
//   Int_t palette[12]={1,2,4,3, 7,9,9,9, 9,7,3,3};
//   Int_t styles[12]= {1,2,3,4, 1,2,3,4, 1,4,3,2};

//   double meanTemp,mean2Temp,sumTemp;

//   // re-binning for the two types of histograms
//   int rebinPt=5;
//   int rebinEta=2;
//   TH1F *hTempPt;
//   int nMeanBins=250;

//   for(int iDir=0;iDir<d.size();iDir++) {
    
//     // arrays for histograms, legends, colors, and line styles
//     histos.Clear();
//     histosEta.Clear();
//     int nPlots=0;
//     //
//     // 
//     TDirectory *d2 = (TDirectory*)(d[iDir]->Get("tree"));
    
//     // b jet PT, always scale to fb
//     TH1F *hTempPt=(TH1F*)(d2->Get("bJetPt"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     // figure out the mean rms of this histogram
//     // do my own calculation
//     meanTemp=0.;
//     mean2Temp=0.;
//     sumTemp=0.;
//     for(int iBin=1;iBin<nMeanBins;iBin++) {
//       meanTemp+=hTempPt->GetBinContent(iBin)*iBin;
//       mean2Temp+=hTempPt->GetBinContent(iBin)*iBin*iBin;
//       sumTemp+=hTempPt->GetBinContent(iBin);
//     }
//     meanTemp=meanTemp/sumTemp;
//     mean2Temp=mean2Temp/sumTemp;
//     cout<<"Mean for Born bPt is "<<hTempPt->GetMean()<<" and RMS is "<<hTempPt->GetRMS()<<endl;
//     cout<<"my mean "<<meanTemp<<", my rms is "<<TMath::Sqrt(mean2Temp-pow(meanTemp,2))<<endl;
//     histos.Add(hTempPt);
//     legends[nPlots]="b Born";
//     nPlots++;
//     // also add eta plot to other clonesarray
//     TH1F *bEta=(TH1F*) (d2->Get("bJetEta"))->Clone();
//     bEta->Scale(1000./bEta->GetBinWidth(1)/((double) rebinEta));
//     histosEta.Add(bEta);
    
//     // bbar jet PT,
//     hTempPt=(TH1F*)(d2->Get("bbarJetPt"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     // figure out the mean rms of this histogram
//     // do my own calculation
//     meanTemp=0.;
//     mean2Temp=0.;
//     sumTemp=0.;
//     for(int iBin=1;iBin<nMeanBins;iBin++) {
//       meanTemp+=hTempPt->GetBinContent(iBin)*iBin;
//       mean2Temp+=hTempPt->GetBinContent(iBin)*iBin*iBin;
//       sumTemp+=hTempPt->GetBinContent(iBin);
//     }
//     meanTemp=meanTemp/sumTemp;
//     mean2Temp=mean2Temp/sumTemp;
//     cout<<"Mean for Born bbar Pt is "<<hTempPt->GetMean()<<" and RMS is "<<hTempPt->GetRMS()<<endl;
//     cout<<"my mean "<<meanTemp<<", my rms is "<<TMath::Sqrt(mean2Temp-pow(meanTemp,2))<<endl;
//     histos.Add(hTempPt);
//     legends[nPlots]="#bar{b} Born";
//     nPlots++;
//     // also add eta plot to other clonesarray
//     bEta=(TH1F*) (d2->Get("bbarJetEta"))->Clone();
//     bEta->Scale(1000./bEta->GetBinWidth(1)/((double) rebinEta));
//     histosEta.Add(bEta);
    
//     d2 = (TDirectory*)(d[iDir]->Get("nlo_all"));
//     hTempPt=(TH1F*)(d2->Get("bJetPt"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     // figure out the mean and rms of this histogram
//     // do my own calculation
//     meanTemp=0.;
//     mean2Temp=0.;
//     sumTemp=0.;
//     for(int iBin=1;iBin<nMeanBins;iBin++) {
//       meanTemp+=hTempPt->GetBinContent(iBin)*iBin;
//       mean2Temp+=hTempPt->GetBinContent(iBin)*iBin*iBin;
//       sumTemp+=hTempPt->GetBinContent(iBin);
//     }
//     meanTemp=meanTemp/sumTemp;
//     mean2Temp=mean2Temp/sumTemp;
//     cout<<"Mean for order alpha_s bPt is "<<hTempPt->GetMean()<<" and RMS is "<<hTempPt->GetRMS()<<endl;
//     cout<<"my mean "<<meanTemp<<", my rms is "<<TMath::Sqrt(mean2Temp-pow(meanTemp,2))<<endl;
//     histos.Add(hTempPt);
//     legends[nPlots]="b O(#alpha_{s})";
//     nPlots++;
//     // also add eta plot to other clonesarray
//     bEta=(TH1F*) (d2->Get("bJetEta"))->Clone();
//     bEta->Scale(1000./bEta->GetBinWidth(1)/((double) rebinEta));
//     histosEta.Add(bEta);
    
//     // bbar jet PT,
//     hTempPt=(TH1F*)(d2->Get("bbarJetPt"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     // figure out the mean and rms of this histogram
//     // do my own calculation
//     meanTemp=0.;
//     mean2Temp=0.;
//     sumTemp=0.;
//     for(int iBin=1;iBin<nMeanBins;iBin++) {
//       meanTemp+=hTempPt->GetBinContent(iBin)*iBin;
//       mean2Temp+=hTempPt->GetBinContent(iBin)*iBin*iBin;
//       sumTemp+=hTempPt->GetBinContent(iBin);
//     }
//     meanTemp=meanTemp/sumTemp;
//     mean2Temp=mean2Temp/sumTemp;
//     cout<<"Mean for order alpha_s bbar Pt is "<<hTempPt->GetMean()<<" and RMS is "<<hTempPt->GetRMS()<<endl;
//     cout<<"my mean "<<meanTemp<<", my rms is "<<TMath::Sqrt(mean2Temp-pow(meanTemp,2))<<endl;
//     histos.Add(hTempPt);
//     legends[nPlots]="#bar{b} O(#alpha_{s})";
//     nPlots++;
//     // also add eta plot to other clonesarray
//     bEta=(TH1F*) (d2->Get("bbarJetEta"))->Clone();
//     bEta->Scale(1000./bEta->GetBinWidth(1)/((double) rebinEta));
//     histosEta.Add(bEta);
    
    
//     // finally, plot!
//     int smoothen=50;
//     // plot without scaling
//     CombineHistos(histos,legends,"bbbar_compare","jet E_{T} [GeV]","#sigma [fb/GeV]",palette,styles,1,smoothen,rebinPt,
// 		  true,false);
//     // and write the plot to file
//     c1->SaveAs(PlotTargetDir+"/histo_bJetbbarJet"+dsuffix[iDir]);
    
//     // and once scaled
//     CombineHistos(histos,legends,"bbbar_compare","jet E_{T} [GeV]","#sigma [fb/GeV]",palette,styles,1,smoothen,rebinPt,
// 		  true,true);
//     // and write the plot to file
//     c1->SaveAs(PlotTargetDir+"/histo_bJetbbarJet_scaled"+dsuffix[iDir]);
    
//     // plot eta without scaling
//     smoothen=50;
//     CombineHistos(histosEta,legends,"bbbar_compare_eta","jet #eta","#sigma [fb]",palette,styles,1,smoothen,rebinEta,
// 		  true,false);
//     // and write the plot to file
//     c1->SaveAs(PlotTargetDir+"/histo_bJetbbarJetEta"+dsuffix[iDir]);
//   }

//   return 0;
// }

// //-------------------------------------------------------------------------
// //
// // Make plots comparing b jet PT for parton level info, leading jet, and best jet
// //  Note: This still has to be made to work!!
// int makebEffPlot(void) 
// {
//   gROOT->ProcessLine(".L ../rootutils/CombineHistos.C");

//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   TCanvas *c1 = new TCanvas("topbbbar","",50,44,600,500);
//   // make more space for the Y-axis title
//   c1->SetLeftMargin( .22); // default is 10%
//   c1->SetBottomMargin(0.15);

//   std::vector<TDirectory*> d;
//   // plot parton distributions
//   // and after cuts
//   d.push_back((TDirectory*)file->Get("08_Histogramming_bbbar"));
//   TString dsuffix[2];
//   dsuffix[0]="_aftercuts";
//   for(int i=0;i<2;i++) dsuffix[i]+=PLOTFILETYPE;

//   TObjArray histos,histosEta;
//   TString legends[12]={"all","Born","O(#alpha_{s})","no dec",
// 		       "FINAL","initial a","initial b","initial c",
// 		       "svc ini","svc fin","svc dec","SDEC"};
//   Int_t palette[12]={1,2,4,3, 7,9,9,9, 9,7,3,3};
//   Int_t styles[12]= {1,2,3,4, 1,2,3,4, 1,4,3,2};


//   // re-binning for the two types of histograms
//   int rebinPt=4;
//   int rebinEta=2;
//   TH1F *hTempPt;
//   int nMeanBins=250;

//   for(int iDir=0;iDir<d.size();iDir++) {
    
//     // arrays for histograms, legends, colors, and line styles
//     histos.Clear();
//     int nPlots=0;
//     //
//     // 
//     TDirectory *d2 = (TDirectory*)(d[iDir]->Get("tree_nlo"));
    
//     // b jet PT, always scale to fb
//     TH1F *hTempPt=(TH1F*)(d2->Get("bJetPtAll"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     histos.Add(hTempPt);
//     legends[nPlots]="all events";
//     nPlots++;
    
    
//     // b jet PT if b jet is the best jet,
//     hTempPt=(TH1F*)(d2->Get("bJetPtBgJet"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     histos.Add(hTempPt);
//     legends[nPlots]="best-jet is b jet";
//     nPlots++;
     
//     // b jet PT if b jet is the leading jet,
//     hTempPt=(TH1F*)(d2->Get("bJetPtLeadJet"))->Clone();
//     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
//     histos.Add(hTempPt);
//     legends[nPlots]="leading jet is b jet";
//     nPlots++;
     
// //     // b jet PT if b jet is the non-best jet,
// //     hTempPt=(TH1F*)(d2->Get("bJetPtNonBgJet"))->Clone();
// //     hTempPt->Scale(1000./hTempPt->GetBinWidth(1)/((double)rebinPt));
// //     histos.Add(hTempPt);
// //     legends[nPlots]="non-best-jet is b jet";
// //     nPlots++;
     
//     // finally, plot!
//     int smoothen=20;
//     // plot without scaling
//     // and feed in all the arguments because we have to shift over the legend.
//     // CombineHistos(HistosArray,LegendsArray,Title,XTitle,Ytitle,PaletteArray,StyleArray,
//     //               LegendCornerMode,Smoothen,Rebin,DrawLine,Normalize,XMin,XMax,XMinCutoff,
//     //               YMin,YMax,LegendXMin)
//     CombineHistos(histos,legends,"bEff_compare","b-jet E_{T} [GeV]","#sigma [fb/GeV]",palette,styles,1,
// 		  smoothen,rebinPt,true,false,0.,200.,-1.,-99999.,-1.,0.6);
//     // and write the plot to file
//     c1->SaveAs(PlotTargetDir+"/histo_bEff_compare"+dsuffix[iDir]);

//   }
//   return 0;
// }

// //--------------------------------------------------------------------------------------
// //
// // make some plots of cos theta between the b from top and the gluon
// // 
// //
// int makeCosThetaPlots(void) 
// {
//   gROOT->ProcessLine(".L ../rootutils/CombineHistos.C");

//   TCanvas *c1 = new TCanvas("topbbbar","",50,44,600,500);
//   // make more space for the Y-axis title
//   c1->SetLeftMargin( .22); // default is 10%
//   c1->SetBottomMargin(0.15);

//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   TObjArray histos;
//   int nPlots=0;
//   TString legends[18]={"O(#alpha_{s}) no d","decay","Born","no dec",
// 		       "FINAL","initial a","initial b","initial c",
// 		       "svc ini","svc fin","svc dec","decay",
// 		       "NLO","O(#alpha_{s}) sum","#O(alpha_{s}), exc. decay","INIT",
// 		       "FINAL","SDEC"};
//   Int_t palette[18]={4,2,4,3, 37,9,9,9, 9,7,3,3, 1,4,2,49, 4,2};
//   Int_t styles[18]= {1,2,3,4, 1,2,3,4, 1,4,3,2, 1,3,3,3, 1,2};
  

//   // plot parton distributions
//   // before any cuts
//   TDirectory *d=(TDirectory*)file->Get("00_Histogramming_Parton");

//   TString dsuffix="_parton";
//   dsuffix+=PLOTFILETYPE;

//   TDirectory *d2 = (TDirectory*)(d->Get("nlo_nodec"));
//   TH1F* temphist;
//   temphist=(TH1F*) (d2->Get("gluonBCosThetaTopRest"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="O(#alpha_{s}) nd";
//   nPlots++;
//   d2 = (TDirectory*)(d->Get("decay"));
//   temphist=(TH1F*) (d2->Get("gluonBCosThetaTopRest"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="decay";
//   nPlots++;
  
//   // finally, plot!
//   int smoothen=10;
//   int rebin=1;
//   CombineHistos(histos,legends,"gluonBCosThetaTopRest","cos(#Delta#theta(gluon,b))_{top rest frame}","#sigma [fb]",
// 		palette,styles,1,smoothen,rebin,true,false);
//   // and write the plot to file
//   c1->SaveAs(PlotTargetDir+"/histo_gluonBCosThetaTopRest"+dsuffix);
  
 
//   // also make plots after cuts using the bg jet!
//   //
//   histos.Clear();
//   d=(TDirectory*)file->Get("06_Histogramming_FinalTopMass");
//   dsuffix="_aftercuts";
//   dsuffix+=PLOTFILETYPE;


//   d2 = (TDirectory*)(d->Get("nlo_nodec"));
//   temphist=(TH1F*) (d2->Get("Jet3BgJetCosThetaTopRest"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="O(#alpha_{s}) nd";
//   nPlots++;
//   d2 = (TDirectory*)(d->Get("decay"));
//   temphist=(TH1F*) (d2->Get("Jet3BgJetCosThetaTopRest"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1));
//   histos.Add(temphist);
//   legends[nPlots]="decay";
//   nPlots++;
  
//   // finally, plot!
//   int smoothen=400;
//   int rebin=1;
//   CombineHistos(histos,legends,"Jet3BgJetCosThetaTopRest","cos(#Delta#theta(jet_{3},jet_{best}))_{top rest frame}",
// 		"#sigma [fb]",palette,styles,1,smoothen,rebin,true,false);
//   // and write the plot to file
//   c1->SaveAs(PlotTargetDir+"/histo_jet3BgJetCosThetaTopRest"+dsuffix);

//   cout<<"End of makeCosThetaPlots"<<endl;
//   return 0;
// }


// //--------------------------------------------------------------------------------------
// //
// // make some plots of top quark helicity (i.e. cos theta), in two frames
// // this is an updated version after looking at the t-channel.
// // 
// //
// int makeTopHelicityPlots(void) 
// {
//   cout<<"beginning of makeTopHelicityPlots !"<<endl;
//   gROOT->ProcessLine(".L ../rootutils/CombineHistos.C");

//   //cout<<"creating canvas"<<endl;
//   TCanvas *c1 = new TCanvas("topbbbar","",50,44,600,500);
//   // make more space for the Y-axis title
//   c1->SetLeftMargin( .22); // default is 10%
//   c1->SetBottomMargin(0.15);

//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);

//   TObjArray histosArray[9];
//   TObjArray histos;
 
//   int nPlots=2;
//   TString dsuffix[9]={"Hel_parton","Opt_parton",
// 		       "Hel_parton_CMAll",
// 		       "Hel_BgTop_aftercuts","Opt_BgTop_aftercuts",
// 		       "Hel_BgTop_aftercuts_CMAll",
// 		       "Hel_BgTop_3j","Opt_BgTop_3j",
// 		       "Hel_BgTop_3j_CMAll"};
//   for(int i=0;i<9;i++) dsuffix[i]+=PLOTFILETYPE;
//   TString basisString[9]={"t)_{helicity basis","q)_{optimal basis",
// 			   "t)_{helicity basis",
// 			   "t)_{helicity basis","q)_{optimal basis",
// 			   "t)_{helicity basis",
// 			   "t)_{helicity basis","q)_{optimal basis",
// 			   "t)_{helicity basis"};

//   // when do 3-jet events start?
//   int legends3jStartIndex=6;
//   TString *legends,legends_incl[3]={"NLO","Born","O(#alpha_{s})"};
//   TString legends_3j[3]={"Parton level","Reconstructed events",""};
//   Int_t palette[18]={1,2,4,3, 37,9,9,9, 9,7,3,3, 1,4,2,49, 4,2};
//   Int_t styles[18]= {1,2,4,4, 1,2,3,4, 1,4,3,2, 1,3,3,3, 1,2};

//   ////////////////////////////////////////////////////////
//   // start by plotting only the W helicity
//   TDirectory *d=(TDirectory*)file->Get("02_Histogramming_TopSpin");
//   TDirectory *d2;
//   TH1F* temphist;
//   int rebin=4;
//   int smoothen=100;
//   legends=legends_incl;


//   //////////////////////////////////////////////////////
//   // now plot polarization and calculate various polarization numbers

//   // plot parton distributions
//   // before any cuts
//   d=(TDirectory*)file->Get("02_Histogramming_TopSpin");
  
//   for(int iAr=0;iAr<9;iAr++) {
//     histosArray[iAr].Clear();
//   }
//   rebin=4;

//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[0].Add(temphist);
//   temphist=(TH1F*) (d2->Get("PartonCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[1].Add(temphist);
  
//   d2 = (TDirectory*)(d->Get("tree"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[0].Add(temphist);
//   temphist=(TH1F*) (d2->Get("PartonCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[1].Add(temphist);

//   d2 = (TDirectory*)(d->Get("nlo_all"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[0].Add(temphist);
//   temphist=(TH1F*) (d2->Get("PartonCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[1].Add(temphist);

//   // also parton level, using all final state objects to reconstruct CM
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[2].Add(temphist);
//   d2 = (TDirectory*)(d->Get("tree"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[2].Add(temphist);
//   d2 = (TDirectory*)(d->Get("nlo_all"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[2].Add(temphist);

  
//   // and after cuts: using the tagged top 
//   d=(TDirectory*)file->Get("07_Histogramming_TopSpin");
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[3].Add(temphist);
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[4].Add(temphist);

//   d2 = (TDirectory*)(d->Get("tree"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[3].Add(temphist);
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[4].Add(temphist);

//   d2 = (TDirectory*)(d->Get("nlo_all"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[3].Add(temphist);
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[4].Add(temphist);

//   // also tag top, using all final state objects to reconstruct CM
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[5].Add(temphist);
//   d2 = (TDirectory*)(d->Get("tree"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[5].Add(temphist);
//   d2 = (TDirectory*)(d->Get("nlo_all"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[5].Add(temphist);

//   //
//   // and considering only the 3-jet bin after cuts: using the bg top 
//   //
//   d=(TDirectory*)file->Get("14_Histogramming_TopSpin");
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[6].Add(temphist);
//   temphist=(TH1F*) (d2->Get("PartonCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[7].Add(temphist);
  
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHel"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[6].Add(temphist);
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaOpt"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[7].Add(temphist);

//   // also tag top, using all final state objects to reconstruct CM
//   d=(TDirectory*)file->Get("14_Histogramming_TopSpin");
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("PartonCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[8].Add(temphist);
  
//   d2 = (TDirectory*)(d->Get("tree_nlo"));
//   temphist=(TH1F*) (d2->Get("BgTopCosThetaHelCMAll"))->Clone();
//   temphist->Scale(1000./temphist->GetBinWidth(1)/((double)rebin));
//   histosArray[8].Add(temphist);


//   TH1F* myHist;
//   //
//   //
//   // now loop over the four pairs of histograms and do some math and plot
//   for(int i=0;i<9;i++) {
//     cout<<"Name: "<<dsuffix[i]<<endl;
//     legends=legends_incl;
//     if(i>=legends3jStartIndex) legends=legends_3j;
//     // loop over the histograms and calculate the degree of polarization as well as the asymmetry.
//     double dpol,asym,aNeg,aPos;
//     for(int iHist=0;iHist<histosArray[i].GetEntries();iHist++) {
//       myHist=(TH1F*)histosArray[i][iHist];
//       // only continue of this histogram has non-zero integral
//       if(myHist->Integral()==0.) continue;
    
//       cout<<legends[iHist].Data()<<": "<<endl;
//       dpol=0.;
//       for(int iBin=1;iBin<myHist->GetNbinsX()+1;iBin++) {
// 	//cout<<" iBin "<<iBin<<", center "<<myHist->GetBinCenter(iBin);
// 	//cout<<", content"<<myHist->GetBinContent(iBin)<<endl;
// 	dpol+=myHist->GetBinCenter(iBin)*myHist->GetBinContent(iBin);
//       } // end of loop over bins
      
//       dpol=-3.*dpol/myHist->Integral();
//       cout<<"  Degree of polarization is "<<dpol<<endl;
//       // the two top polarization fractions:
//       cout<<"  Fraction of + Polarization is "<<(1.+dpol)/2.<<", and of - polarization "<<(1.-dpol)/2.<<endl;
//       // also calculate the asymmetry:
//       aNeg=myHist->Integral(1,50);
//       aPos=myHist->Integral(51,101);
//       asym = (aNeg - aPos) / (aNeg + aPos);
//       cout<<"  Asymmetry is "<<asym<<endl;
//     } // end of loop over tree/alpha_s histogram

//     // finally, plot!
//     smoothen=5;
//     if(i<2) {
//       // parton, lots of smoothing
//       smoothen=400;
//     }
//     //cout<<"plot: "<<i<<", "<<histosArray[i].GetEntries()<<endl;
//     //
//     // CombineHistos(HistosArray,LegendsArray,Title,XTitle,Ytitle,PaletteArray,StyleArray,
//     //               LegendCornerMode,Smoothen,Rebin,DrawLine,Normalize,XMin,XMax,XMinCutoff,
//     //               YMin,YMax,LegendXMin)
//     CombineHistos(histosArray[i],legends,"costhetapol","cos#theta(e,"+basisString[i]+"}","#sigma [fb]",
// 		  palette,styles,1,smoothen,rebin,DRAWLINE,false,-1.,-1.,-1.,-10,-1.);
    
    
//     // and write the plot to file
//     c1->SaveAs(PlotTargetDir+"/histo_CosTheta"+dsuffix[i]);
    
//     //
//     // and the same thing, but normalized to unit area
//     // remove the O_alphas 
//     histosArray[i].RemoveLast();
//     CombineHistos(histosArray[i],legends,"costhetapol","cos#theta(e,"+basisString[i]+"}","",
// 		  palette,styles,1,smoothen,rebin,DRAWLINE,true,-1.,-1.,-1.,-10,-1.);    
//     // and write the plot to file
//     c1->SaveAs(PlotTargetDir+"/histo_CosTheta_norm"+dsuffix[i]);
  
//   }


//   cout<<"End of makeHelicityPlots"<<endl;
//   return 0;
// }



// //--------------------------------------------------------------------------------------
// //
// // make some plots of top quark helicity (i.e. cos theta), in two frames
// // 
// //
// int makeTopologicalPlots(void) 
// {
//   gROOT->ProcessLine(".L plotSingleHistogram.C");
  
  
//   // open the histogram file
//   TFile  *file=new TFile(DefaultHistoFile);
//   //TFile  *file=new TFile("../../Histograms-tree_nlo.root");
  
//   std::vector<TDirectory*> d;
//   // plot parton distributions
//   //  after cuts
//   d.push_back((TDirectory*)file->Get("09_Histogramming_TopologicalVars"));
  
//   TString dsuffix[4];
//   dsuffix[0]=PLOTFILETYPE;
  
//   for(int i=0;i<1;i++) {
//     plotHistogram(d[i],"HT","H_{T} [GeV]","sums",dsuffix[i],1,2,50,0.,600.);
//     plotHistogram(d[i],"HT","H_{T} [GeV]","alpha_s_only",dsuffix[i],1,2,50,0.,600.);
//     plotHistogram(d[i],"HT","H_{T} [GeV]","alpha_s_tree_scale4",dsuffix[i],1,2,50,0.,600.);
//   }
  
  
//   cout<<"End of makeTopologicalPlots"<<endl;
//   return 0;
// }


// //---------------------------------------------------------------------------
// //
// // helper function: Gaussian
// Double_t Gauss(Double_t *x, Double_t *par)
// {
//   Double_t arg = 0;
//   if (par[2]) arg = (x[0] - par[1])/par[2];
  
//   Double_t sig = par[0]*TMath::Exp(-0.5*arg*arg);
//   return sig;
// }

