///////////////////////////////////////////////////////////////////////////
// header file: Particle
// 
// Description: 
//  store information about final state objects.
//
// Author: Reinhard Schwienhorst
// Date: 10/19/2006
//
// Modifications:
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef particle_h
#define particle_h

#include <TLorentzVector.h>
//

class Particle: public TLorentzVector
{
 public:
  //default constructor
  Particle();
  //default constructor
  Particle(const Particle& other);
  Particle(Particle& other);
  // constructor from TLorentzVector
  Particle(const TLorentzVector& other);
  //destructor
  ~Particle();

  // overloaded operators:
  // +=
  Particle& operator+=(const Particle& other);
  // addition:
  Particle operator+(const Particle& other);
  // overloaded assignment operator:
  Particle& operator=(TLorentzVector& other);
  // overloaded assignment operator:
  Particle& operator=(const Particle& other);

  // Setters
  // Set the charge of this particle
  void SetCharge(int iCh) { _charge = static_cast<double>(iCh); };
  void SetCharge(const double& ch) { _charge = ch; };

  // Getters
  // Get the charge of this particle
  double GetCharge() const { return _charge; };
  double charge() const { return _charge; };


 private:
  
  double _charge;  // charge of particle

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(Particle,0)
};


#endif
