///////////////////////////////////////////////////////////////////////////
// header file: Particles
// 
// Description: 
//  read in variables from the EV0 chains and make them available
//  in Object form.
//
// Author: Reinhard Schwienhorst
// Date: 10/19/2006
//
// Modifications:
// 10/19/2006, RS: - initial version only with electrons
//
//
////////////////////////////////////////////////////////////////////////////
#ifndef particles_h
#define particles_h

#include <vector>
#include <string>
#include <iostream>

// MakeClass output:
#include "single_top_analysis/EV0.hpp"
// our own particles
#include "single_top_analysis/Electron.hpp"
//
#include <TObjArray.h>
#include <TLorentzVector.h>
//


class Particles
{
 public:
  //default constructor
  Particles();
  //destructor
  ~Particles();

  // Set the tarGet top mass for top quark constraint in best jet algorithm
  void SetTarGetTopMass(const double& mass) { _tarGetTopMass=mass; };

  // initialize this class 
  void initialize(EV0* eventTree);

  // Create TLorentz Vectors for the particles in the interaction
  int readEvent();

  // Create final state particles and make cuts if necessary (require at least
  // two jets and at least one lepton)
  // return false if these conditions are not fulfilled
  bool CreateFinalState();

  // reconstruct the top in several different ways from the final state objects
  void makeTopQuarks();

  // Set up the particles for the next event
  int GetNextEvent();
  // initialize the event counter to Get a very specific event in the chain
  inline void SetEventCount(int i) { _eventCount=i; };


  // Set and Read the flag that determines whether 
  // Also determine whether we should only process leptons
  // of a specific flavor (0 to process all).
  inline void SetLeptonSelect(int flavor) { _leptonSelect=flavor; };
  inline int GetLeptonSelect() { return _leptonSelect; };

  // Set a normalization factor for all histograms
  inline void SetNormalization(double norm) { _normalization=norm; };

  // Get the actual tree
  inline EV0* GetEV0() const { return _eventTree; };
  
  ////////////////////////////////////
  // object helpers:
  //

  ////////////////////////////////////
  // make the particles available for every event.
  // partons:
  double eventWeight;         // the event weight
  int runNumber;              // run number from the root tree
  int eventNumber;            // event number from the root tree

  std::vector<Electron> electrons;
  // ..... add more here


 private:

  //////////////////////////////
  // reconstruction information
  //
  //
  // the tarGet top mass used in the best jet algorithm
  double _tarGetTopMass;
  // 

  //////////////////////////////////////////
  // The classes that contain the information from the trees:
  EV0 *_eventTree;

  //
  // should we only process certain events?
  int _leptonSelect;     // = 11: electrons, =12: only muons, =0: all

  //
  // Normalization factor for histograms
  double _normalization; // additional normalization factor

  //
  // counters to keep track of where we are in the chain
  int _eventCount;

  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(Particles,0)
};


#endif
