//
// header file: nloanalysis
// 
#ifndef analysis_main_h
#define analysis_main_h

#include <string>

#include "TFile.h"
// 
#include "single_top_analysis/Particles.hpp"
#include "single_top_analysis/CutListProcessor.hpp"
//
// Root includes:
//


class analysis_main: public Particles, public CutListProcessor
{
 public:
  //default constructor
  analysis_main();
  //destructor
  ~analysis_main();

  // open the output histogram file and Create histograms
  void openHistogramFile(const std::string& name) {
    _histoFile = new TFile(name.c_str(), "RECREATE"); _histoFileName=name; };
  // write the histograms
  void writeHistogramFile() {
    if (_histoFile) _histoFile->Write(); };
  // close the output histogram file
  void closeHistogramFile() { if (_histoFile) {
      _histoFile->Close(); delete _histoFile; _histoFile=NULL; } };
  // Get the name of the histogram file
  std::string GetHistogramFileName() { return _histoFileName; };
  
  // parse the command line to extract the names of 
  // the root files with and without gluons and put them into chains.
  Int_t parsecmdline(int argc, char **argv,TChain *loch);
  // 
  // the eventloop:
  void loop();
  //
  // declare these two because they are virtual in the class we are inheriting from
  // they are not really needed.
  void BookHistos(void) {};
  bool Apply() { return true; };
 
 private:  
  // the output histogram file
  TFile *_histoFile; 
  // the histogram file name
  std::string _histoFileName;
  // the number of events to loop over. If it's Set to 0, loop over all events.
  int _numEvents;

  // rs: need to move these into Histogramming_... classes!
  //////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////

  ////////////////////////
  // histograms comparing reconstructed quantities to partons
  //  myTH1F* _hNeutrinoPzRecoParton;
  //myTH1F* _hdRBestJetBQuark;
  //myTH1F* _hdPhiBestJetBQuark;
  //myTH1F* _hdRLeadingJetBQuark;
  //myTH1F* _hdPhiLeadingJetBQuark;

  /////////////////////////////////////////////////////////////////////////


  ////////////////////////////////////////
  // needed to run with Root:
  ClassDef(analysis_main,0)
};


#endif
